package Microsoft::AdCenter::V7::CustomerManagementService::LanguageType;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V7::CustomerManagementService::LanguageType - Represents "LanguageType" in Microsoft AdCenter Customer Management Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

Danish
Dutch
English
Finnish
French
German
Italian
Japanese
Norwegian
Portuguese
Spanish
Swedish

=cut

sub Danish {
    return 'Danish';
}

sub Dutch {
    return 'Dutch';
}

sub English {
    return 'English';
}

sub Finnish {
    return 'Finnish';
}

sub French {
    return 'French';
}

sub German {
    return 'German';
}

sub Italian {
    return 'Italian';
}

sub Japanese {
    return 'Japanese';
}

sub Norwegian {
    return 'Norwegian';
}

sub Portuguese {
    return 'Portuguese';
}

sub Spanish {
    return 'Spanish';
}

sub Swedish {
    return 'Swedish';
}

1;
